<?php

/**
 * @file
 * Contains Drupal\chessboard_flexible\PiecePlacement.
 */

namespace Drupal\chessboard_flexible;

use Drupal\chessboard\PiecePlacement as StandardPiecePlacement;
use Drupal\chessboard\PiecePlacementInterface;

/**
 * Represents piece placement on the chessboard.
 */
final class PiecePlacement extends StandardPiecePlacement implements PiecePlacementInterface {

  /**
   * The number of board files.
   *
   * @var int
   */
  private $boardWidth;

  /**
   * Constructs a new flexible piece placement object.
   */
  public function __construct($board_width) {
    $this->boardWidth = (int) $board_width;
  }

  /**
   * Gets the number of board files.
   *
   * @return int
   *   The number of board files.
   */
  public function getBoardWidth() {
    return $this->boardWidth;
  }

  /**
   * Implements PiecePlacementInterface::getPieceCode().
   */
  public function getPieceCode($fen_rank, $fen_file) {
    $index = $fen_rank * $this->getBoardWidth() + $fen_file;
    if (isset($this->value[$index])) {
      return $this->value[$index];
    }
    else {
      throw new \RuntimeException('Index invalid or out of range');
    }
  }

}
