<?php

/**
 * @file
 * Contains Drupal\chessboard\PiecePlacementBase.
 */

namespace Drupal\chessboard;

/**
 * Represents piece placement on the chessboard.
 */
abstract class PiecePlacementBase {

  /**
   * The piece placement value.
   *
   * @var string
   */
  protected $value;

  /**
   * Gets the piece placement value.
   *
   * @return string
   */
  public function getValue() {
    return $this->value;
  }

  /**
   * Sets the piece placement value.
   *
   * @param string $value
   *   The piece placement value or NULL to unset the data value.
   * @param bool $notify
   *   (optional) Whether to notify the parent object of the change. Defaults to
   *   TRUE. If a property is updated from a parent object, set it to FALSE to
   *   avoid being notified again.
   *
   * @throws \InvalidArgumentException
   *   If the value input is inappropriate.
   * @throws \Drupal\Core\TypedData\ReadOnlyException
   *   If the data is read-only.
   */
  public function setValue($value, $notify = TRUE) {
    $this->value = $value;
    // Notify the parent of any changes.
    if ($notify && isset($this->parent)) {
      $this->parent->onChange($this->name);
    }
  }

}
